@@ -2,8 +2,10 @@ __all__ = [
     "Gui", "HtmlGui", "ThreePartGui", "SystemTrayGui",
     "ArgsGui", "ArgFrame",
     "widget",
+    "SysTraySchedule",
 ]
 
 from .gui import Gui, HtmlGui, ThreePartGui, SystemTrayGui
 from .argsgui import ArgsGui, ArgFrame
 from . import widget
+from .schedule import SysTraySchedule
